@@ -15,7 +15,7 @@ var scripts = document.getElementsByTagName('script');
 var index = scripts.length - 1;
 var myScriptUrl = scripts[index].src;
 var ma = myScriptUrl.match( /^((https?:\/\/)?[^\/]+(:(\d+))?)\// );
-var yote_scr_url = ma && ma.length > 1 ? ma[ 1 ] : '';
+var yote_src_url = ma && ma.length > 1 ? ma[ 1 ] : '';
 
 // the whole yote object.
 if( typeof $.yote === 'object' ) {
@@ -23,7 +23,7 @@ if( typeof $.yote === 'object' ) {
 }
 
 $.yote = {
-    url:yote_scr_url,
+    url:yote_src_url,
     has_updated :false,
     guest_token:0,
     token:0,
@@ -46,146 +46,146 @@ $.yote = {
 
     init:function( appname, token ) {
         token = token ? token : $.cookie('yoken');
-	    $.yote.token = token || 0;
+	$.yote.token = token || 0;
         var ret;
-	    this.message( {
-	        async:false,
-	        cmd:'fetch_initial',
-	        data:{ t:token,a:appname },
-	        passhandler:function( initial_data ) {	    
-		        if( typeof initial_data === 'object' && initial_data.get(  'root' ) && initial_data.get(  'app' ) ) {
-		            var yote_root = initial_data.get(  'root' ); 
+	this.message( {
+	    async:false,
+	    cmd:'fetch_initial',
+	    data:{ t:token,a:appname },
+	    passhandler:function( initial_data ) {	    
+		if( typeof initial_data === 'object' && initial_data.get(  'root' ) && initial_data.get(  'app' ) ) {
+		    var yote_root = initial_data.get(  'root' ); 
                     yote_root._app_id = yote_root.id;
-		            $.yote.yote_root = yote_root;
-		            $.yote.objs[ yote_root.id ] = yote_root;
+		    $.yote.yote_root = yote_root;
+		    $.yote.objs[ yote_root.id ] = yote_root;
 
-		            var app = initial_data.get( 'app' ) || yote_root;
-		            app._app_id = app.id;
-		            $.yote._app_id = app.id;
-		            $.yote.default_app = app;
-		            $.yote.default_appname = appname;
-		            $.yote.objs[ app.id ] = app;
+		    var app = initial_data.get( 'app' ) || yote_root;
+		    app._app_id = app.id;
+		    $.yote._app_id = app.id;
+		    $.yote.default_app = app;
+		    $.yote.default_appname = appname;
+		    $.yote.objs[ app.id ] = app;
 
-		            $.yote.login_obj   = initial_data.get(  'login' );
-		            $.yote.acct_obj    = initial_data.get(  'account' );
+		    $.yote.login_obj   = initial_data.get(  'login' );
+		    $.yote.acct_obj    = initial_data.get(  'account' );
                     $.yote.acct_obj._app_id = app.id;
 
-		            $.yote.guest_token = initial_data.get(  'guest_token' );
+		    $.yote.guest_token = initial_data.get(  'guest_token' );
 
-		            ret = app;
-		        }
-		        else {
-		            console.log( "ERROR in init for app '" + appname + "' Load did not work" );
-		        }
-	        },
-	        failhandler:function( err ) {
-		        console.log( "ERROR in init for app '" + appname + "' : " + err );
-	        }
-	    } );
+		    ret = app;
+		}
+		else {
+		    console.log( "ERROR in init for app '" + appname + "' Load did not work" );
+		}
+	    },
+	    failhandler:function( err ) {
+		console.log( "ERROR in init for app '" + appname + "' : " + err );
+	    }
+	} );
         return ret;
     }, //init
 
     reinit:function( token ) {
-	    if( ! this.default_app || this.need_reinit ) {
-	        this.init( this.default_appname, token );
-	        this.need_reinit = false;
-	        return true;
-	    }
-	    return false;
+	if( ! this.default_app || this.need_reinit ) {
+	    this.init( this.default_appname, token );
+	    this.need_reinit = false;
+	    return true;
+	}
+	return false;
     }, //reinit
 
     fetch_default_app:function() {
-	    return this.default_app || this.fetch_root();
+	return this.default_app || this.fetch_root();
     },
 
     fetch_account:function() {
-	    if( this.default_app ) {
-	        if( ! this.acct_obj ) {
-		        this.acct_obj = this.default_app.account();
-	        }
-	        return this.acct_obj;
+	if( this.default_app ) {
+	    if( ! this.acct_obj ) {
+		this.acct_obj = this.default_app.account();
 	    }
-	    return undefined;
+	    return this.acct_obj;
+	}
+	return undefined;
     },
 
     fetch_app:function(appname,passhandler,failhandler) {
-	    var yote_root = this.fetch_default_app();
-	    if( typeof yote_root === 'object' ) {
-	        var ret = yote_root.fetch_app_by_class( appname );
-	        ret._app_id = ret.id;
-	        return ret;
-	    } else if( typeof failhanlder === 'function' ) {
-	        failhandler('lost connection to yote server');
-	    } else {
-	        _error('lost connection to yote server');
-	    }
+	var yote_root = this.fetch_default_app();
+	if( typeof yote_root === 'object' ) {
+	    var ret = yote_root.fetch_app_by_class( appname );
+	    ret._app_id = ret.id;
+	    return ret;
+	} else if( typeof failhanlder === 'function' ) {
+	    failhandler('lost connection to yote server');
+	} else {
+	    _error('lost connection to yote server');
+	}
     }, //fetch_app
 
     fetch_root:function() {
-	    var r = $.yote.yote_root;
-	    if( ! r ) {
-	        r = this.message( {
-		        async:false,
-		        cmd:'fetch_root'
-	        } );
-	        $.yote.yote_root = r;
-	    }
-	    return r;
+	var r = $.yote.yote_root;
+	if( ! r ) {
+	    r = this.message( {
+		async:false,
+		cmd:'fetch_root'
+	    } );
+	    $.yote.yote_root = r;
+	}
+	return r;
     }, //fetch_root
 
     // return not only root but login if applicable
     // returns root, app, login, account
     fetch_initial:function( token, appname ) {
-	    if( r && typeof r === 'object' && r.length() > 2 ) {
-	        return [ r.get(0), r.get(1), r.get(2), r.get(3) ];
-	    }
+	if( r && typeof r === 'object' && r.length() > 2 ) {
+	    return [ r.get(0), r.get(1), r.get(2), r.get(3) ];
+	}
     }, //fetch_initial
 
     get_by_id:function( id ) {
-	    return $.yote.objs[id+''] || $.yote.fetch_default_app().fetch(id).get(0);
+	return $.yote.objs[id+''] || $.yote.fetch_default_app().fetch(id).get(0);
     },
 
     has_root_permissions:function() {
-	    return this.is_logged_in() && 1*this.get_login().get_is_root();
+	return this.is_logged_in() && 1*this.get_login().get_is_root();
     },
 
     get_login:function() {
-	    return this.login_obj;
+	return this.login_obj;
     }, //get_login
 
     is_logged_in:function() {
-	    return typeof this.login_obj === 'object';
+	return typeof this.login_obj === 'object';
     }, //is_logged_in
 
     login:function( handle, password, passhandler, failhandler ) {
-	    var root = this.fetch_root();
-	    if( typeof root === 'object' ) {
-	        root.login( { h:handle, p:password },
-			            function(res) {
-			                $.yote.token = res.get( 't' ) || 0;
-			                $.yote.login_obj = res.get( 'l' );
-			                $.cookie( 'yoken', $.yote.token, { path : '/' } );
-			                if( typeof passhandler === 'function' ) {
-				                passhandler(res);
-			                }
-			            },
-			            failhandler );
-	        return $.yote.login_obj;
-	    } else if( typeof failhanlder === 'function' ) {
-	        failhandler('lost connection to yote server');
-	    } else {
-	        _error('lost connection to yote server');
-	    }
+	var root = this.fetch_root();
+	if( typeof root === 'object' ) {
+	    root.login( { h:handle, p:password },
+			function(res) {
+			    $.yote.token = res.get( 't' ) || 0;
+			    $.yote.login_obj = res.get( 'l' );
+			    $.cookie( 'yoken', $.yote.token, { path : '/' } );
+			    if( typeof passhandler === 'function' ) {
+				passhandler(res);
+			    }
+			},
+			failhandler );
+	    return $.yote.login_obj;
+	} else if( typeof failhanlder === 'function' ) {
+	    failhandler('lost connection to yote server');
+	} else {
+	    _error('lost connection to yote server');
+	}
     }, //login
 
     logout:function() {
-	    $.yote.fetch_root().logout();
-	    $.yote.login_obj = undefined;
-	    $.yote.acct_obj = undefined;
-	    $.yote.default_app = undefined;
-	    $.yote.token = 0;
-	    $.yote._dump_cache();
-	    $.cookie( 'yoken', '', { path : '/' } );
+	$.yote.fetch_root().logout();
+	$.yote.login_obj = undefined;
+	$.yote.acct_obj = undefined;
+	$.yote.default_app = undefined;
+	$.yote.token = 0;
+	$.yote._dump_cache();
+	$.cookie( 'yoken', '', { path : '/' } );
     }, //logout
 
     /* general functions */
@@ -198,36 +198,36 @@ $.yote = {
         var cmd    = params.cmd;
         var obj_id = params.obj_id || ''; //id to act on
 
-	    root.upload_count = 0;
+	root.upload_count = 0;
 
-	    if( ! app_id ) app_id = $.yote._app_id || 0;
-	    if( ! obj_id ) obj_id = 0;
+	if( ! app_id ) app_id = $.yote._app_id || 0;
+	if( ! obj_id ) obj_id = 0;
 
         var url = $.yote.url + '/_/' + app_id + '/' + obj_id + '/' + cmd;
 
-	    var uploads = root._functions_in( data );
-	    if( uploads.length > 0 ) {
-	        return root.upload_message( params, uploads );
-	    }
+	var uploads = root._functions_in( data );
+	if( uploads.length > 0 ) {
+	    return root.upload_message( params, uploads );
+	}
         if( async == 0 ) {
             root._disable();
         }
-	    var encoded_data = $.base64.encode( JSON.stringify( { d : data } ) );
+	var encoded_data = $.base64.encode( JSON.stringify( { d : data } ) );
         var get_data = $.yote.token + "/" + $.yote.guest_token;
-	    var resp;
+	var resp;
 
         if( $.yote.debug == true ) {
-	        console.log("\noutgoing : " + cmd + '  : ' + url + '/' + get_data + '-------------------------' );
-	        console.log( data );
-	    }
+	    console.log("\noutgoing : " + cmd + '  : ' + url + '/' + get_data + '-------------------------' );
+	    console.log( data );
+	}
 
-	    $.ajax( {
-	        async:async,
-	        cache: false,
-	        contentType: "application/json; charset=utf-8",
-	        data : encoded_data,
-	        dataFilter:function(a,b) {
-		        if( $.yote.debug == true ) {
+	$.ajax( {
+	    async:async,
+	    cache: false,
+	    contentType: "application/json; charset=utf-8",
+	    data : encoded_data,
+	    dataFilter:function(a,b) {
+		if( $.yote.debug == true ) {
                     console.log( 'raw incoming ' );
                     var len = 160;
                     for( var i=0; i<a.length; i+=len ) {
@@ -235,68 +235,68 @@ $.yote = {
                     }
                     // print out eadch substring on a line
                 }
-		        return a;
-	        },
+		return a;
+	    },
 
-	        error:function(a,b,c) { 
+	    error:function(a,b,c) { 
                 root._error(a); 
             },
-	        success:function( data ) {
-		        if( $.yote.debug == true ) {
+	    success:function( data ) {
+		if( $.yote.debug == true ) {
                     console.log( ['incoming ', data ] );
                 }
                 if( typeof data !== 'undefined' ) {
-		            resp = ''; //for returning synchronous
+		    resp = ''; //for returning synchronous
 
-		            if( typeof data.err === 'undefined' ) {
-			            //dirty objects that may need a refresh
+		    if( typeof data.err === 'undefined' ) {
+			//dirty objects that may need a refresh
                         $.yote.has_updated = false;
-			            if( typeof data.d === 'object' ) {
+			if( typeof data.d === 'object' ) {
                             $.yote.has_updated = true;                            
-			                for( var oid in data.d ) {
-				                if( root._is_in_cache( oid ) ) {
-				                    
-				                    var cached = root.objs[ oid + '' ];
-				                    for( fld in cached._d ) {
-					                    //take off old getters/setters
-					                    delete cached['get_'+fld];
-				                    }
-				                    cached._d = data.d[ oid ];
+			    for( var oid in data.d ) {
+				if( root._is_in_cache( oid ) ) {
+				    
+				    var cached = root.objs[ oid + '' ];
+				    for( fld in cached._d ) {
+					//take off old getters/setters
+					delete cached['get_'+fld];
+				    }
+				    cached._d = data.d[ oid ];
 
-				                    for( fld in cached._d ) {
-					                    //add new getters/setters
-					                    cached['get_'+fld] = (function(fl) { return function() { return this.get(fl) } } )(fld);
-				                    }
-				                }
-			                } //each dirty
-			            } //if dirty
+				    for( fld in cached._d ) {
+					//add new getters/setters
+					cached['get_'+fld] = (function(fl) { return function() { return this.get(fl) } } )(fld);
+				    }
+				}
+			    } //each dirty
+			} //if dirty
 
-			            if( typeof data.r === 'object' ) {
-			                resp = root._create_obj( data.r, app_id );
-		                    if( typeof params.passhandler === 'function' ) {
-				                params.passhandler( resp );
-			                }
-			            } else if( typeof data.r === 'undefined' ) {
-		                    if( typeof params.passhandler === 'function' ) {
-				                params.passhandler();
-			                }
-			            } else {
-			                resp = data.r.substring( 1 );
-		                    if( typeof params.passhandler === 'function' ) {
-				                params.passhandler( resp );
-			                }
-		                }
-		            } else if( typeof params.failhandler === 'function' ) {
-			            console.log( data.err );
-		                params.failhandler(data.err);
+			if( typeof data.r === 'object' ) {
+			    resp = root._create_obj( data.r, app_id );
+		            if( typeof params.passhandler === 'function' ) {
+				params.passhandler( resp );
+			    }
+			} else if( typeof data.r === 'undefined' ) {
+		            if( typeof params.passhandler === 'function' ) {
+				params.passhandler();
+			    }
+			} else {
+			    resp = data.r.substring( 1 );
+		            if( typeof params.passhandler === 'function' ) {
+				params.passhandler( resp );
+			    }
+		        }
+		    } else if( typeof params.failhandler === 'function' ) {
+			console.log( data.err );
+		        params.failhandler(data.err);
                     } //error case. no handler defined
                 } else {
                     console.log( "Success reported but no response data received" );
                 }
-	        },
-	        type:'POST',
-	        url:url + '/' + get_data
-	    } );
+	    },
+	    type:'POST',
+	    url:url + '/' + get_data
+	} );
         if( ! async ) {
             root._reenable();
             return resp;
@@ -308,14 +308,14 @@ $.yote = {
        For example some_yote_obj->do_something( { a : 'a data', file_up = upload( '#myfileuploader' ) } )
     */
     upload:function( selector_id ) {
-	    var uctxt = 'u' + this.upload_count++;
-	    $( selector_id ).attr( 'name', uctxt );
-	    return (function(uct, sel_id) {
-	        return function( return_selector_id ) { //if given no arguments, just returns the name given to the file input control
-		        if( return_selector_id ) return sel_id;
-		        return uctxt;
-	        };
-	    } )( uctxt, selector_id );
+	var uctxt = 'u' + this.upload_count++;
+	$( selector_id ).attr( 'name', uctxt );
+	return (function(uct, sel_id) {
+	    return function( return_selector_id ) { //if given no arguments, just returns the name given to the file input control
+		if( return_selector_id ) return sel_id;
+		return uctxt;
+	    };
+	} )( uctxt, selector_id );
     }, //upload
 
     /* Should have a upload_multiple. This would pass the files as filename -> data pairs, and include a filenames list */
@@ -326,7 +326,7 @@ $.yote = {
     upload_message:function( params, uploads ) {
 
 
-	    // for multiple, upload the files in order, then get the filehelper objs as callbacks and then make the call
+	// for multiple, upload the files in order, then get the filehelper objs as callbacks and then make the call
 
         var root   = this;
         var data   = root._translate_data( params.data || {}, true );
@@ -337,88 +337,88 @@ $.yote = {
 
         var url = $.yote.url + '/_u/' + app_id + '/' + obj_id + '/' + cmd;
 
-	    root.iframe_count++;
-	    var iframe_name = 'yote_upload_' + root.iframe_count;
-	    var form_id = 'yote_upload_form_' + root.iframe_count;
-	    var iframe = $( '<iframe id="' + iframe_name + '" name="' + iframe_name + '" style="position;absolute;top:-9999px;display:none" /> ').appendTo( 'body' );
-	    var form = '<form id="' + form_id + '" target="' + iframe_name + '" method="post" enctype="multipart/form-data" />';
-	    var upload_selector_ids = uploads.map( function( x ) { return x(true) } );
-	    var cb_list = [];
-	    $( upload_selector_ids.join(',') ).each(
-	        function( idx, domEl ) {
-		        $( this ).prop( 'disabled', false );
-		        cb_list.push(  $( 'input:checkbox', this ) );
-	        }
-	    );
-	    if( $.yote.debug == true ) {
-	        console.log("\noutgoing " + url + '-------------------------' );
-	        console.log( data );
+	root.iframe_count++;
+	var iframe_name = 'yote_upload_' + root.iframe_count;
+	var form_id = 'yote_upload_form_' + root.iframe_count;
+	var iframe = $( '<iframe id="' + iframe_name + '" name="' + iframe_name + '" style="position;absolute;top:-9999px;display:none" /> ').appendTo( 'body' );
+	var form = '<form id="' + form_id + '" target="' + iframe_name + '" method="post" enctype="multipart/form-data" />';
+	var upload_selector_ids = uploads.map( function( x ) { return x(true) } );
+	var cb_list = [];
+	$( upload_selector_ids.join(',') ).each(
+	    function( idx, domEl ) {
+		$( this ).prop( 'disabled', false );
+		cb_list.push(  $( 'input:checkbox', this ) );
 	    }
+	);
+	if( $.yote.debug == true ) {
+	    console.log("\noutgoing " + url + '-------------------------' );
+	    console.log( data );
+	}
 
-	    var form_sel = $( upload_selector_ids.join(',') ).wrapAll( form ).parent('form').attr('action',url);
-	    $( '#' + form_id ).append( '<input type=hidden name=d value="' + $.base64.encode(JSON.stringify( {d:data} ) ) + '">');
-	    $( '#' + form_id ).append( '<input type=hidden name=t value="' + $.yote.token + '">');
-	    $( '#' + form_id ).append( '<input type=hidden name=gt value="' + $.yote.guest_token + '">');
+	var form_sel = $( upload_selector_ids.join(',') ).wrapAll( form ).parent('form').attr('action',url);
+	$( '#' + form_id ).append( '<input type=hidden name=d value="' + $.base64.encode(JSON.stringify( {d:data} ) ) + '">');
+	$( '#' + form_id ).append( '<input type=hidden name=t value="' + $.yote.token + '">');
+	$( '#' + form_id ).append( '<input type=hidden name=gt value="' + $.yote.guest_token + '">');
 
-	    for( var i=0; i<cb_list.length; i++ ) {
-	        cb_list[ i ].removeAttr('checked');
-	        cb_list[ i ].attr('checked', true);
-	    }
-	    var resp;
+	for( var i=0; i<cb_list.length; i++ ) {
+	    cb_list[ i ].removeAttr('checked');
+	    cb_list[ i ].attr('checked', true);
+	}
+	var resp;
 
-	    var xx = form_sel.submit(function() {
-	        iframe.load(function() {
-		        var contents = $(this).contents().get(0).body.innerHTML;
-		        while( contents.match( /^\s*</ ) ) {
-		            contents = contents.replace( /^\s*<\/?[^\>]*>/, '' );
-		            contents = contents.replace( /<\/?[^\>]*>\s*$/, '' );
-		        }
-		        $( '#' + iframe_name ).remove();
-		        try {
-		            resp = JSON.parse( contents );
-		            if( $.yote.debug == true ) {
-			            console.log([ 'incoming ', resp ] );
-		            }
+	var xx = form_sel.submit(function() {
+	    iframe.load(function() {
+		var contents = $(this).contents().get(0).body.innerHTML;
+		while( contents.match( /^\s*</ ) ) {
+		    contents = contents.replace( /^\s*<\/?[^\>]*>/, '' );
+		    contents = contents.replace( /<\/?[^\>]*>\s*$/, '' );
+		}
+		$( '#' + iframe_name ).remove();
+		try {
+		    resp = JSON.parse( contents );
+		    if( $.yote.debug == true ) {
+			console.log([ 'incoming ', resp ] );
+		    }
 
                     if( typeof resp !== 'undefined' ) {
-			            if( typeof resp.err === 'undefined' ) {
-			                //dirty objects that may need a refresh
-			                if( typeof resp.d === 'object' ) {
-				                for( var oid in resp.d ) {
-				                    if( root._is_in_cache( oid ) ) {
-					                    var cached = root.objs[ oid + '' ];
-					                    for( fld in cached._d ) {
-					                        //take off old getters/setters
-					                        delete cached['get_'+fld];
-					                    }
-					                    cached._d = resp.d[ oid ];
-					                    for( fld in cached._d ) {
-					                        //add new getters/setters
-					                        cached['get_'+fld] = (function(fl) { return function() { return this.get(fl) } } )(fld);
-					                    }
-				                    }
-				                }
-			                }
-		                    if( typeof params.passhandler === 'function' ) {
-				                if( typeof resp.r === 'object' ) {
-				                    params.passhandler( root._create_obj( ret.r, this._app_id ) );
-				                } else if( typeof resp.r === 'undefined' ) {
-				                    params.passhandler();
-				                } else {
-				                    params.passhandler( resp.r.substring( 1 ) );
-				                }
-		                    }
-			            } else if( typeof params.failhandler === 'function' ) {
-		                    params.failhandler(resp.err);
-			            } //error case. no handler defined
+			if( typeof resp.err === 'undefined' ) {
+			    //dirty objects that may need a refresh
+			    if( typeof resp.d === 'object' ) {
+				for( var oid in resp.d ) {
+				    if( root._is_in_cache( oid ) ) {
+					var cached = root.objs[ oid + '' ];
+					for( fld in cached._d ) {
+					    //take off old getters/setters
+					    delete cached['get_'+fld];
+					}
+					cached._d = resp.d[ oid ];
+					for( fld in cached._d ) {
+					    //add new getters/setters
+					    cached['get_'+fld] = (function(fl) { return function() { return this.get(fl) } } )(fld);
+					}
+				    }
+				}
+			    }
+		            if( typeof params.passhandler === 'function' ) {
+				if( typeof resp.r === 'object' ) {
+				    params.passhandler( root._create_obj( ret.r, this._app_id ) );
+				} else if( typeof resp.r === 'undefined' ) {
+				    params.passhandler();
+				} else {
+				    params.passhandler( resp.r.substring( 1 ) );
+				}
+		            }
+			} else if( typeof params.failhandler === 'function' ) {
+		            params.failhandler(resp.err);
+			} //error case. no handler defined
                     } else {
-			            console.log( "Success reported but no response data received" );
+			console.log( "Success reported but no response data received" );
                     }
-		        } catch(err) {
-		            root._error(err);
-		        }
-	        } )
-	    } ).submit();
+		} catch(err) {
+		    root._error(err);
+		}
+	    } )
+	} ).submit();
     }, //upload_message
 
 
@@ -535,8 +535,8 @@ $.yote = {
                         var new_ret = [];
                         for( var i=0; i<ret.length; i++ ) {
                             var k = ret[ i ];
-                                if( this._filter_function( k, _hash[ k ] ) )
-                                    new_ret.push( k );
+                            if( this._filter_function( k, _hash[ k ] ) )
+                                new_ret.push( k );
                         }
                         ret = new_ret;
                     } 
@@ -581,136 +581,136 @@ $.yote = {
         }
         return node;
     }, //data_wrapper
-        
+    
 
     // TODO : use prototype for the _create_obj
     _create_obj:function(data,app_id) { //creates the javascript proxy object for the perl object.
-	    var root = this;
-	    if( data.id != null && typeof data.id !== 'undefined' && root._is_in_cache( data.id ) ) {
-	        return root.objs[ data.id + '' ];
-	    }
-	    var retty = (function(x,ai) {
-	        var o = {
-		        _app_id:ai,
+	var root = this;
+	if( data.id != null && typeof data.id !== 'undefined' && root._is_in_cache( data.id ) ) {
+	    return root.objs[ data.id + '' ];
+	}
+	var retty = (function(x,ai) {
+	    var o = {
+		_app_id:ai,
                 _dirty:false,
-		        _d:{},
-		        id:x.id+'',
-		        class:x.c,
+		_d:{},
+		id:x.id+'',
+		class:x.c,
                 _staged:{},
-		        length:function() {
-		            var cnt = 0;
-		            for( key in this._d ) {
-			            ++cnt;
-		            }
-		            return cnt;
-		        },
-		        equals:function(oth) {
-		            return typeof oth === 'object' && oth.id && oth.id == this.id;
-		        },
-		        keys:function() {
-		            return Object.keys( this._d );
-		        },
-		        values:function() {
-		            var thing = this;
-		            return this.keys().map(function(a) { return thing.get(a); } );
-		        },
-		        sort:function(sortfun) {
-		            var res = this.values().sort( sortfun );
-		            return res;
-		        }
-	        };
-	        if( o.class == 'HASH' ) {
-		        o.to_hash = function() {
-		            var hash = {};
-		            for( var key in this._d ) {
-			            hash[ key ] = this.get( key );
-		            }
-		            return hash;
-		        };
-	        }
-	        else if( o.class == 'ARRAY' ) {
-		        o.to_list = function() {
-		            var list = [];
-		            for( var i=0; i < this.length(); i++ ) {
-			            list[i] = this.get(i);
-		            }
-		            return list;
-		        };
-	        }
-	        else {
-		        if( typeof x.m === 'object' && x.m !== null ) { // set methods
-		            for( m in x.m ) {
-			            o[x.m[m]] = (function(key,thobj) {
-			                return function( params, passhandler, failhandler, use_async ) {
-				                return root.message( {
-				                    async: use_async ? true : false,
-				                    app_id:this._app_id,
-				                    cmd:key,
-				                    data:params,
-				                    failhandler:failhandler,
+		length:function() {
+		    var cnt = 0;
+		    for( key in this._d ) {
+			++cnt;
+		    }
+		    return cnt;
+		},
+		equals:function(oth) {
+		    return typeof oth === 'object' && oth.id && oth.id == this.id;
+		},
+		keys:function() {
+		    return Object.keys( this._d );
+		},
+		values:function() {
+		    var thing = this;
+		    return this.keys().map(function(a) { return thing.get(a); } );
+		},
+		sort:function(sortfun) {
+		    var res = this.values().sort( sortfun );
+		    return res;
+		}
+	    };
+	    if( o.class == 'HASH' ) {
+		o.to_hash = function() {
+		    var hash = {};
+		    for( var key in this._d ) {
+			hash[ key ] = this.get( key );
+		    }
+		    return hash;
+		};
+	    }
+	    else if( o.class == 'ARRAY' ) {
+		o.to_list = function() {
+		    var list = [];
+		    for( var i=0; i < this.length(); i++ ) {
+			list[i] = this.get(i);
+		    }
+		    return list;
+		};
+	    }
+	    else {
+		if( typeof x.m === 'object' && x.m !== null ) { // set methods
+		    for( m in x.m ) {
+			o[x.m[m]] = (function(key,thobj) {
+			    return function( params, passhandler, failhandler, use_async ) {
+				return root.message( {
+				    async: use_async ? true : false,
+				    app_id:this._app_id,
+				    cmd:key,
+				    data:params,
+				    failhandler:failhandler,
                                     obj_id:this.id,
-				                    passhandler:passhandler
-				                } ); //sending message
-			                } } )(x.m[m],x);
-		            } //each method
-		        } // if methods were included in the return value of the call
-	        } // if object
+				    passhandler:passhandler
+				} ); //sending message
+			    } } )(x.m[m],x);
+		    } //each method
+		} // if methods were included in the return value of the call
+	    } // if object
 
-	        o.get = function( key ) {
-		        var val = this._staged[key] || this._d[key];
-		        if( typeof val === 'undefined' ) return undefined;
-		        if( typeof val === 'object' ) return val;
-		        if( typeof val === 'function' ) return val;
+	    o.get = function( key ) {
+		var val = this._staged[key] || this._d[key];
+		if( typeof val === 'undefined' ) return undefined;
+		if( typeof val === 'object' ) return val;
+		if( typeof val === 'function' ) return val;
 
-		        if( val.substring(0,1) != 'v' ) {
-		            var obj = root.objs[val+''];
-		            if( ! obj ) {
-			            var ret = $.yote.fetch_default_app().fetch(val);
-			            if( ! ret ) return undefined; //this can happen if an authorized user logs out
-			            obj = ret.get(0);
-		            }
-		            obj._app_id = this._app_id;
+		if( val.substring(0,1) != 'v' ) {
+		    var obj = root.objs[val+''];
+		    if( ! obj ) {
+			var ret = $.yote.fetch_default_app().fetch(val);
+			if( ! ret ) return undefined; //this can happen if an authorized user logs out
+			obj = ret.get(0);
+		    }
+		    obj._app_id = this._app_id;
                     return obj;
-		        }
-		        var ret = val.substring(1);
+		}
+		var ret = val.substring(1);
                 return typeof ret * 1 !== 'NaN' ? ret : ret * 1;
-	        };
-	        
-	        o.is = function( othero ) {
-		        var k = this.id;
-		        var ok = othero ? othero.id : undefined;
-		        return k !== 'undefined' && k == ok;
-	        }
+	    };
+	    
+	    o.is = function( othero ) {
+		var k = this.id;
+		var ok = othero ? othero.id : undefined;
+		return k !== 'undefined' && k == ok;
+	    }
 
-	        o._get_id = function( key ) {
-		        // returns the id ( if any of the item specified by the key )
-		        var val = this._d[key];
-		        return val && val.substring(0,1) != 'v' ? val : undefined;
-	        },
+	    o._get_id = function( key ) {
+		// returns the id ( if any of the item specified by the key )
+		var val = this._d[key];
+		return val && val.substring(0,1) != 'v' ? val : undefined;
+	    },
 
-	        o.set = function( key, val, failh, passh ) {
-		        this._stage( key, val );
-		        this._send_update( undefined, failh, passh );
-		        delete this._staged[ key ];
+	    o.set = function( key, val, failh, passh ) {
+		this._stage( key, val );
+		this._send_update( undefined, failh, passh );
+		delete this._staged[ key ];
                 if( ! this[ 'set_' + key ] ) 
                     this[ 'set_' + key ] = (function(k) { return function(val,fh,ph) { return this.set(k,val,fh,ph) } } )(key);
-		        return val;
-	        };
+		return val;
+	    };
 
-	        // get fields
-	        if( typeof x.d === 'object' && x.d !== null ) {
-		        for( fld in x.d ) {
-		            var val = x.d[fld];
-		            if( typeof val === 'object' && val != null ) {
-			            o._d[fld] = (function(xx) { return root._create_obj( xx, app_id ); })(val);
-		            }
-		            else {
-			            o._d[fld] = (function(xx) { return xx; })(val);
-		            }
-		            o['get_'+fld] = (function(fl) { return function() { return this.get(fl) } } )(fld);
-		            o['set_'+fld] = (function(fl) { return function(val,fh,ph) { return this.set(fl,val,fh,ph) } } )(fld);
-		        }
-	        }
+	    // get fields
+	    if( typeof x.d === 'object' && x.d !== null ) {
+		for( fld in x.d ) {
+		    var val = x.d[fld];
+		    if( typeof val === 'object' && val != null ) {
+			o._d[fld] = (function(xx) { return root._create_obj( xx, app_id ); })(val);
+		    }
+		    else {
+			o._d[fld] = (function(xx) { return xx; })(val);
+		    }
+		    o['get_'+fld] = (function(fl) { return function() { return this.get(fl) } } )(fld);
+		    o['set_'+fld] = (function(fl) { return function(val,fh,ph) { return this.set(fl,val,fh,ph) } } )(fld);
+		}
+	    }
 
             // stages functions for updates
             o._stage = function( key, val ) {
@@ -722,11 +722,11 @@ $.yote = {
 
             // resets staged info
             o._reset = function( field ) {
-		        if( field ) {
-		            delete this._staged[ field ];
-		        } else {
+		if( field ) {
+		    delete this._staged[ field ];
+		} else {
                     this._staged = {};
-		        }
+		}
             }
 
             o._is_dirty = function(field) {
@@ -783,27 +783,27 @@ $.yote = {
                 } );
             }; //_send_update
 
-	        if( o.id && o.id.substring(0,1) != 'v' ) {
-		        root.objs[o.id+''] = o;
-	        }
-	        return o;
+	    if( o.id && o.id.substring(0,1) != 'v' ) {
+		root.objs[o.id+''] = o;
+	    }
+	    return o;
         } )(data,app_id);
-	    return retty;
+	return retty;
     }, //_create_obj
 
     _disable:function() {
-	    if( $( 'body' ).css("cursor") !== "wait" ) {
+	if( $( 'body' ).css("cursor") !== "wait" ) {
             $("*").css("cursor", "wait");
             this.enabled = $(':enabled');
-	        $.each( this.enabled, function(idx,val) { val.disabled = true; } );
-	    }
+	    $.each( this.enabled, function(idx,val) { val.disabled = true; } );
+	}
     }, //_disable
 
     _dump_cache:function() {
         this.objs = {};
-	    this.apps = {};
-	    this.yote_root   = undefined;
-	    this.default_app = undefined;
+	this.apps = {};
+	this.yote_root   = undefined;
+	this.default_app = undefined;
         this._app_id = undefined;
     },
 
@@ -814,19 +814,19 @@ $.yote = {
     },
 
     _functions_in:function( thing ) {
-	    var to_ret, res;
-	    if( typeof thing === 'function' ) return [thing];
-	    if( typeof thing === 'object' || typeof thing === 'array' ) {
-	        to_ret = [];
-	        for( x in thing ) {
-		        res = this._functions_in( thing[ x ] );
-		        for( y in res ) {
-		            to_ret.push( res[ y ] );
-		        }
-	        }
-	        return to_ret;
+	var to_ret, res;
+	if( typeof thing === 'function' ) return [thing];
+	if( typeof thing === 'object' || typeof thing === 'array' ) {
+	    to_ret = [];
+	    for( x in thing ) {
+		res = this._functions_in( thing[ x ] );
+		for( y in res ) {
+		    to_ret.push( res[ y ] );
+		}
 	    }
-	    return [];
+	    return to_ret;
+	}
+	return [];
     }, //_functions_in
 
     _is_in_cache:function(id) {
@@ -849,28 +849,28 @@ $.yote = {
             // this case is for paramers being sent thru message
             // that will not get ids.
             var ret;
-	        if (data instanceof Array) {
-		        ret = [];
-	        } else {
-		        ret = Object();
-	        }
+	    if (data instanceof Array) {
+		ret = [];
+	    } else {
+		ret = Object();
+	    }
             for( var key in data ) {
                 ret[key] = this._translate_data( data[key], run_functions );
             }
             return ret;
         }
-	    if( typeof data === 'function' ) {
-	        if( run_functions )
-		        return data();
-	        return data;
-	    }
+	if( typeof data === 'function' ) {
+	    if( run_functions )
+		return data();
+	    return data;
+	}
         return 'v' + data;
     }, //_translate_data
 
     _untranslate_data:function(data) {
-	    if( typeof data === 'function' ) {
-	        return data;
-	    }
+	if( typeof data === 'function' ) {
+	    return data;
+	}
         if( data.substring(0,1) == 'v' ) {
             return data.substring(1);
         }
